@@ -455,7 +455,7 @@ def read_status(voltime, cfg, ind_rad=0):
     dayinfo = voltime.strftime('%y%j')
     timeinfo = voltime.strftime('%H%M')
     basename = 'ST'+cfg['RadarName'][ind_rad]+dayinfo
-    if cfg['path_convention'][ind_rad] == 'RT':
+    if cfg['path_convention'] == 'RT':
         datapath = cfg['datapath'][ind_rad]+'ST'+cfg['RadarName'][ind_rad]+'/'
     else:
         datapath = cfg['datapath'][ind_rad]+dayinfo+'/'+basename+'/'
